===================================
Reading and analyzing data with Neo
===================================

Getting started
===============

.. loading data with an IO module

.. link to list of IO modules

.. navigating through the tree

.. plotting data

.. link to examples. You now know enough to start using Neo. If you want to know more, read on.

NumPy
=====

.. Neo is based on NumPy, with extra constraints from quantities and Neo

.. treating Neo data objects like numpy arrays, quantity arrays, converting between them


Data types
==========

.. AnalogSignal, IrregularlySampledSignal, SpikeTrain, Event, Epoch, ImageSequence


Annotations
===========

.. and array annotations


Dataset structure
=================

.. Blocks, segments, etc.

.. linking objects (Group, ChannelView)


Performance and memory consumption
==================================

.. lazy loading


Examples
========

.. links to examples gallery